#!/usr/bin/env perl

my @DATA = qw(
    accoutrements
    acrobatics
    aerodynamics
    aeronautics
    aesthetics
    amends
    annals
    anopheles
    apparatus
    arrears
    asparagus
    assizes
    athletics
    auspices
    backwoods
    bacteria
    banns
    barracks
    basics
    battlements
    bedclothes
    bellows
    belongings
    betters
    bifocals
    billiards
    binoculars
    bitters
    blandishments
    bleachers
    blinkers
    blues
    bourgeois
    bowels
    breeches
    briefs
    britches
    brussels
    butterfingers
    clippers
    clothes
    commons
    confines
    contents
    contretemps
    corps
    credentials
    crossbones
    crossroads
    damages
    dealings
    denims
    dentures
    depths
    devotions
    diggings
    doings
    doldrums
    downs
    downstairs
    dramatics
    dungarees
    dynamics
    earnings
    eatables
    eaves
    economics
    electrodynamics
    electronics
    entrails
    environs
    ergonomics
    ethics
    eugenics
    faeces
    feces
    filings
    finances
    footlights
    fries
    furnishings
    gallows
    gasworks
    genetics
    genitals
    glassworks
    glitterati
    goggles
    goods
    gravitas
    grits
    grounds
    gymnastics
    hackles
    handcuffs
    haves
    headquarters
    herpes
    hijinks
    histrionics
    hubris
    humanities
    hydraulics
    hysterics
    chassis
    checkers
    ides
    illuminations
    incidentals
    ironworks
    italics
    jackanapes
    jeans
    jinks
    jitters
    kinetics
    knickers
    kurus
    latitudes
    leavings
    leftovers
    leggings
    likes
    linguistics
    lodgings
    loggerheads
    logistics
    mains
    makings
    manners
    mathematics
    means
    measles
    media
    memoirs
    metaphysics
    microelectronics
    miniseries
    mips
    mockers
    mores
    multimedia
    mumps
    munitions
    news
    nutria
    nylons
    oats
    odds
    oils
    oilskins
    olympics
    oodles
    optics
    orthodontics
    outskirts
    overalls
    pajamas
    pampas
    pantaloons
    panties
    pants
    papers
    paras
    paratroops
    particulars
    patois
    payola
    pediatrics
    phonemics
    phonetics
    physics
    pickings
    pincers
    plainclothes
    pliers
    politeness
    politics
    precis
    proceedings
    proceeds
    prospects
    pyjamas
    rations
    ravages
    ravings
    refreshments
    regards
    remains
    rendezvous
    reparations
    respects
    revers
    rights
    riches
    rudiments
    savings
    scads
    scissors
    seconds
    semantics
    series
    shades
    shallows
    shambles
    shears
    shorts
    singles
    slacks
    species
    specifics
    spectacles
    splits
    spoils
    statics
    statistics
    subtitles
    summons
    superficies
    supplies
    surroundings
    suspenders
    sweepstakes
    takings
    tatters
    teens
    telecommunications
    tenterhooks
    testes
    thanks
    theatricals
    thermodynamics
    tights
    toiletries
    toils
    tongs
    trappings
    travels
    triceps
    troops
    tropics
    trousers
    tweeds
    tweezers
    underclothes
    underpants
    vapours
    vibes
    vicissitudes
    vitals
    wages
    wanderings
    wares
    waterworks
    waxworks
    whereabouts
    whites
    winnings
    withers
    woolens
    woollens
    workings
    writings
);

sub analyze() {		## no critic qw(Subroutines::ProhibitSubroutinePrototypes)
    foreach (@DATA) {
        print "$_\tNNS\t$_\n";
    }
    return;
}

if ( $ARGV[0] eq '-a' ) { analyze(); }
elsif ( $ARGV[0] eq '-g' ) {
    foreach (@DATA) { print "$_\t$_\n"; }
}
elsif ( $ARGV[0] eq '-d' ) {
    foreach (@DATA) { print "$_\n"; }
}
else { die "Invalid usage: use option -a, -g or -d\n"; }
