package Treex::EN;
$Treex::EN::VERSION = '2.20151102';
use strict;
use warnings;
use Treex::Unilang;

1;

__END__
#Module is here for synchronizing EN with Unilang
#TODO - synopsis, example of parsing
#a) from commandline
#b) directly from perl
=pod

=encoding utf8

=head1 NAME

Treex::EN - collection of blocks for processing English

=head1 VERSION

version 2.20151102

=head1 DESCRIPTION

=head1 AUTHOR

Tomáš Kraut <kraut@ufal.mff.cuni.cz>

=head1 COPYRIGHT AND LICENSE

Copyright © 2011 by Institute of Formal and Applied Linguistics, Charles University in Prague

This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
